@@ -2,7 +2,7 @@
 
     Source file for  sendpgppass  (sends passphrase to PGPdaemon).
 
-    Copyright (C) 1994  Richard Gooch
+    Copyright (C) 1994-1997  Richard Gooch
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -48,14 +48,17 @@
 
     Updated by      Richard Gooch   16-JUL-1994: Changed to use of  scrub_file
 
-    Last updated by Richard Gooch   3-DEC-1994: Took account of changes to
+    Updated by      Richard Gooch   3-DEC-1994: Took account of changes to
   connect_to_pgpdaemon  .
 
+    Last updated by Richard Gooch   25-SEP-1997: Used new ERRSTRING macro.
+
 
 */
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #ifdef _AIX
@@ -117,84 +120,78 @@ char *envp[];
     char secring_filename[STRING_LENGTH];
     char txt[STRING_LENGTH];
     char *pgp_argv[7];
-    ERRNO_TYPE errno;
-    extern char *sys_errlist[];
 
     if ( ( pgppath = getenv ("PGPPATH") ) == NULL )
     {
-	(void) fprintf (stderr, "No PGPPATH environment variable\n");
+	fprintf (stderr, "No PGPPATH environment variable\n");
 	exit (RV_UNDEF_ERROR);
     }
     /*  Get userID  */
     if ( ( userid = get_userid (pgppath) ) == NULL )
     {
-	(void) fprintf (stderr, "Could not get userID\n");
+	fprintf (stderr, "Could not get userID\n");
 	exit (RV_UNDEF_ERROR);
     }
-    (void) fprintf (stderr, "UserID: \"%s\"\n", userid);
+    fprintf (stderr, "UserID: \"%s\"\n", userid);
     if (set_env ("PGPPASSFD", "0") != 0)
     {
-	(void) fprintf (stderr,
-			"Error setting PGPPASSFD environment variable\n");
+	fprintf (stderr, "Error setting PGPPASSFD environment variable\n");
 	exit (RV_UNDEF_ERROR);
     }
     /*  Get the secret keyring  */
-    (void) sprintf (secring_filename, "%s/secring.pgp", pgppath);
+    sprintf (secring_filename, "%s/secring.pgp", pgppath);
     if ( ( secring_fd = open (secring_filename, O_RDONLY, 0) ) < 0 )
     {
-	(void) fprintf (stderr, "Error opening file: \"%s\"\t%s\n",
-			secring_filename, sys_errlist[errno]);
+	fprintf (stderr, "Error opening file: \"%s\"\t%s\n",
+		 secring_filename, ERRSTRING);
 	exit (RV_UNDEF_ERROR);
     }
     if (fstat (secring_fd, &statbuf) != 0)
     {
-	(void) fprintf (stderr, "Error stat'ing file: \"%s\"\t%s\n",
-			secring_filename, sys_errlist[errno]);
-	(void) close (secring_fd);
+	fprintf (stderr, "Error stat'ing file: \"%s\"\t%s\n",
+		 secring_filename, ERRSTRING);
+	close (secring_fd);
 	exit (RV_UNDEF_ERROR);
     }
     secring_bytes = statbuf.st_size;
     if ( ( buf = m_alloc (secring_bytes) ) == NULL )
     {
-	(void) fprintf (stderr, "Error allocating: %d bytes\n", secring_bytes);
-	(void) close (secring_fd);
+	fprintf (stderr, "Error allocating: %d bytes\n", secring_bytes);
+	close (secring_fd);
 	exit (RV_MEM_ERROR);
     }
     if (read (secring_fd, buf, secring_bytes) < secring_bytes)
     {
-	(void) fprintf (stderr, "Error reading secret keyring\t%s\n",
-			sys_errlist[errno]);
-	(void) close (secring_fd);
+	fprintf (stderr, "Error reading secret keyring\t%s\n", ERRSTRING);
+	close (secring_fd);
 	exit (RV_READ_ERROR);
     }
-    (void) close (secring_fd);
+    close (secring_fd);
     if ( !connect_to_pgpdaemon (pgppath, &to_fd, &from_fd) )
     {
-	(void) fprintf (stderr, "Could not connect to PGPdaemon\n");
+	fprintf (stderr, "Could not connect to PGPdaemon\n");
 	exit (RV_UNDEF_ERROR);
     }
     if ( ( passphrase = mygetpass ("Enter your PGP passphrase: ") ) == NULL )
     {
-	(void) fprintf (stderr, "Error getting passphrase\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
-	(void) close (from_fd);
+	fprintf (stderr, "Error getting passphrase\t%s\n", ERRSTRING);
+	close (to_fd);
+	close (from_fd);
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
     }
     len = strlen (passphrase);
     /*  Now check that passphrase is OK  */
-    (void) sprintf (txt, "%s/sigtest", pgppath);
+    sprintf (txt, "%s/sigtest", pgppath);
     if ( ( fp = fopen (txt, "w") ) == NULL )
     {
-	(void) fprintf (stderr, "Error opening file: \"%s\"\t%s\n",
-			sys_errlist[errno]);
+	fprintf (stderr, "Error opening file: \"%s\"\t%s\n", ERRSTRING);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
     }
-    (void) fprintf (fp, "test line\n");
-    (void) fclose (fp);
+    fprintf (fp, "test line\n");
+    fclose (fp);
     in_fd = -1;
     out_fd = ERROR_FD;
     err_fd = ERROR_FD;
@@ -210,7 +207,7 @@ char *envp[];
     if ( ( child = spawn_job ("pgp", pgp_argv, &in_fd, &out_fd, &err_fd) )
 	< 0 )
     {
-	(void) fprintf (stderr, "Error spawning PGP\n");
+	fprintf (stderr, "Error spawning PGP\n");
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
@@ -218,29 +215,27 @@ char *envp[];
     /*  Send passphrase  */
     if (write (in_fd, passphrase, len) < len)
     {
-	(void) fprintf (stderr, "Error writing passphrase\t%s\n",
-			sys_errlist[errno]);
-	(void) close (in_fd);
-	(void) waitpid (child, &status, 0);
+	fprintf (stderr, "Error writing passphrase\t%s\n", ERRSTRING);
+	close (in_fd);
+	waitpid (child, &status, 0);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
     }
-    (void) close (in_fd);
+    close (in_fd);
     if (waitpid (child, &status, 0) < 0)
     {
-	(void) fprintf (stderr, "Error reaping child\t%s\n",
-			sys_errlist[errno]);
+	fprintf (stderr, "Error reaping child\t%s\n", ERRSTRING);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
     }
-    (void) unlink (txt);
-    (void) sprintf (txt, "%s/sigtest.sig", pgppath);
-    (void) unlink (txt);
+    unlink (txt);
+    sprintf (txt, "%s/sigtest.sig", pgppath);
+    unlink (txt);
     if (status != 0)
     {
-	(void) fprintf (stderr, "Bad child status: %d\n", status);
+	fprintf (stderr, "Bad child status: %d\n", status);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
@@ -249,9 +244,8 @@ char *envp[];
     len = strlen (command);
     if (write (to_fd, command, len) < len)
     {
-	(void) fprintf (stderr, "Error writing command\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
+	fprintf (stderr, "Error writing command\t%s\n", ERRSTRING);
+	close (to_fd);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
@@ -259,9 +253,8 @@ char *envp[];
     len = strlen (passphrase);
     if (write (to_fd, passphrase, len) < len)
     {
-	(void) fprintf (stderr, "Error writing passphrase\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
+	fprintf (stderr, "Error writing passphrase\t%s\n", ERRSTRING);
+	close (to_fd);
 	m_clear ( passphrase, strlen (passphrase) );
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
@@ -270,9 +263,8 @@ char *envp[];
     m_clear ( passphrase, strlen (passphrase) );
     if (write (to_fd, "\n", 1) < 1)
     {
-	(void) fprintf (stderr, "Error writing NEWLINE\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
+	fprintf (stderr, "Error writing NEWLINE\t%s\n", ERRSTRING);
+	close (to_fd);
 	m_clear (buf, secring_bytes);
 	exit (RV_SYS_ERROR);
     }
@@ -280,23 +272,22 @@ char *envp[];
     if (write (to_fd, (char *) &secring_bytes, sizeof secring_bytes) <
 	sizeof secring_bytes)
     {
-	(void) fprintf (stderr, "Error writing secret keyring length\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
+	fprintf (stderr, "Error writing secret keyring length\t%s\n",
+		 ERRSTRING);
+	close (to_fd);
 	m_clear (buf, secring_bytes);
 	exit (RV_WRITE_ERROR);
     }
     /*  Write secret keyring  */
     if (write (to_fd, buf, secring_bytes) < secring_bytes)
     {
-	(void) fprintf (stderr, "Error writing secret keyring data\t%s\n",
-			sys_errlist[errno]);
-	(void) close (to_fd);
+	fprintf (stderr, "Error writing secret keyring data\t%s\n", ERRSTRING);
+	close (to_fd);
 	m_clear (buf, secring_bytes);
 	exit (RV_WRITE_ERROR);
     }
-    (void) close (to_fd);
-    (void) close (from_fd);
+    close (to_fd);
+    close (from_fd);
     /*  Scrub-up  */
     m_clear (buf, secring_bytes);
     m_free (buf);
@@ -304,12 +295,12 @@ char *envp[];
     {
 	if ( !scrub_file (secring_filename, TRUE) )
 	{
-	    (void) fprintf (stderr, "Error scrubbing file: \"%s\"\n",
-			    secring_filename);
+	    fprintf (stderr, "Error scrubbing file: \"%s\"\n",
+		     secring_filename);
 	    exit (RV_UNDEF_ERROR);
 	}
     }
-    (void) sync ();
+    sync ();
 }   /*  End Function main  */
 
 static char *mygetpass (prompt)
@@ -322,26 +313,23 @@ CONST char *prompt;
     char ch;
     int count;
     int fd;
-    ERRNO_TYPE errno;
-    extern char *sys_errlist[];
     static char buffer[STRING_LENGTH];
 
     if ( ( fd = open (TTY, O_RDWR, 0) ) < 0 )
     {
-	(void) fprintf (stderr, "Error opening terminal\t%s\n",
-			sys_errlist[errno]);
+	fprintf (stderr, "Error opening terminal\t%s\n", ERRSTRING);
 	exit (RV_CANNOT_OPEN);
     }
 #ifdef obsolete
-    (void) ioctl (fd, TCGETS, &tty_new);
-    (void) ioctl (fd, TCGETS, &tty_orig);
+    ioctl (fd, TCGETS, &tty_new);
+    ioctl (fd, TCGETS, &tty_orig);
 #else
-    (void) tcgetattr (fd, &tty_new);
-    (void) tcgetattr (fd, &tty_orig);
+    tcgetattr (fd, &tty_new);
+    tcgetattr (fd, &tty_orig);
 #endif
     tty_new.c_lflag &= ~(ECHO | ISIG);
 #ifdef obsolete
-    (void) ioctl (fd, TCSETS, &tty_new);
+    ioctl (fd, TCSETS, &tty_new);
 #else
 #  ifdef TCSANOW
     tcsetattr (fd, TCSANOW, &tty_new);
@@ -349,14 +337,14 @@ CONST char *prompt;
     tcsetattr (fd, 0,  &tty_new);
 #  endif
 #endif
-    (void) fprintf (stderr, "%s", prompt);
+    fprintf (stderr, "%s", prompt);
     fflush (stderr);
     /*  Read from terminal  */
     for (count = 0; count < STRING_LENGTH - 1; ++count)
     {
 	if (read (fd, &ch, 1) < 1)
 	{
-	    (void) fprintf (stderr, "Error reading\t%s\n", sys_errlist[errno]);
+	    fprintf (stderr, "Error reading\t%s\n", ERRSTRING);
 	    exit (RV_READ_ERROR);
 	}
 	if ( (ch == '\n') || (ch == '\r') )
@@ -367,10 +355,10 @@ CONST char *prompt;
 	buffer[count] = ch;
 	buffer[count + 1] = '\0';
     }
-    (void) fprintf (stderr, "\r\n");
+    fprintf (stderr, "\r\n");
     fflush (stderr);
 #ifdef obsolete
-    (void) ioctl (fd, TCSETS, &tty_orig);
+    ioctl (fd, TCSETS, &tty_orig);
 #else
 #  ifdef TCSANOW
     tcsetattr (fd, TCSANOW, &tty_orig);
@@ -394,14 +382,12 @@ char *pgppath;
     FILE *fp;
     char config_filename[STRING_LENGTH];
     char txt[STRING_LENGTH];
-    ERRNO_TYPE errno;
-    extern char *sys_errlist[];
 
-    (void) sprintf (config_filename, "%s/PGPdaemon.config", pgppath);
+    sprintf (config_filename, "%s/PGPdaemon.config", pgppath);
     if ( ( fp = fopen (config_filename, "r") ) == NULL )
     {
-	(void) fprintf (stderr, "Error reading file: \"%s\"\t%s\n",
-			config_filename, sys_errlist[errno]);
+	fprintf (stderr, "Error reading file: \"%s\"\t%s\n",
+		 config_filename, ERRSTRING);
 	exit (RV_CANNOT_OPEN);
     }
     /*  Read in lines  */
@@ -416,7 +402,7 @@ char *pgppath;
 	{
 	    if ( ( userid = ex_str (rest, &rest) ) == NULL )
 	    {
-		(void) fprintf (stderr, "Could not get userID\n");
+		fprintf (stderr, "Could not get userID\n");
 		m_free (keyword);
 		return (NULL);
 	    }
@@ -425,6 +411,6 @@ char *pgppath;
 	}
 	m_free (keyword);
     }
-    (void) fprintf (stderr, "USERID keyword not found\n");
+    fprintf (stderr, "USERID keyword not found\n");
     return (NULL);
 }   /*  End Function get_userid  */
